@@ -40,6 +40,7 @@ OC.L10N.register(
     "Comment:" : "Comment:",
     "You have a new appointment booking \"%s\" from %s" : "You have a new appointment booking \"%s\" from %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Dear %s, %s (%s) booked an appointment with you.",
+    "Location:" : "Location:",
     "A Calendar app for Nextcloud" : "A Calendar app for Nextcloud",
     "Previous day" : "Previous day",
     "Previous week" : "Previous week",
@@ -111,7 +112,6 @@ OC.L10N.register(
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Items in the trash bin are deleted after {numDays} day","Items in the trash bin are deleted after {numDays} days"],
     "Could not update calendar order." : "Could not update calendar order.",
     "Deck" : "Deck",
-    "Hidden" : "Hidden",
     "Internal link" : "Internal link",
     "A private link that can be used with external clients" : "A private link that can be used with external clients",
     "Copy internal link" : "Copy internal link",
@@ -138,10 +138,10 @@ OC.L10N.register(
     "Share with users or groups" : "Share with users or groups",
     "No users or groups" : "No users or groups",
     "Failed to save calendar name and color" : "Failed to save calendar name and color",
-    "Calendar name …" : "Calendar name …",
     "Share calendar" : "Share calendar",
     "Unshare from me" : "Unshare from me",
     "Save" : "Save",
+    "View" : "View",
     "Import calendars" : "Import calendars",
     "Please select a calendar to import into …" : "Please select a calendar to import into …",
     "Filename" : "Filename",
@@ -158,7 +158,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Successfully imported %n event","Successfully imported %n events"],
     "Import partially failed. Imported {accepted} out of {total}." : "Import partially failed. Imported {accepted} out of {total}.",
     "Automatic" : "Automatic",
-    "Automatic ({detected})" : "Automatic ({detected})",
+    "Automatic ({timezone})" : "Automatic ({timezone})",
     "New setting was not saved successfully." : "New setting was not saved successfully.",
     "Navigation" : "Navigation",
     "Previous period" : "Previous period",
@@ -177,24 +177,22 @@ OC.L10N.register(
     "Save edited event" : "Save edited event",
     "Delete edited event" : "Delete edited event",
     "Duplicate event" : "Duplicate event",
-    "Shortcut overview" : "Shortcut overview",
     "or" : "or",
     "Calendar settings" : "Calendar settings",
     "No reminder" : "No reminder",
     "CalDAV link copied to clipboard." : "CalDAV link copied to clipboard.",
     "CalDAV link could not be copied to clipboard." : "CalDAV link could not be copied to clipboard.",
-    "Enable birthday calendar" : "Enable birthday calendar",
-    "Show tasks in calendar" : "Show tasks in calendar",
-    "Enable simplified editor" : "Enable simplified editor",
-    "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
-    "Show weekends" : "Show weekends",
-    "Show week numbers" : "Show week numbers",
-    "Time increments" : "Time increments",
-    "Default reminder" : "Default reminder",
+    "General" : "General",
+    "Personal availability settings" : "Personal availability settings",
     "Copy primary CalDAV address" : "Copy primary CalDAV address",
     "Copy iOS/macOS CalDAV address" : "Copy iOS/macOS CalDAV address",
-    "Personal availability settings" : "Personal availability settings",
-    "Show keyboard shortcuts" : "Show keyboard shortcuts",
+    "Enable birthday calendar" : "Enable birthday calendar",
+    "Show tasks in calendar" : "Show tasks in calendar",
+    "Show weekends" : "Show weekends",
+    "Show week numbers" : "Show week numbers",
+    "Editing" : "Editing",
+    "Default reminder" : "Default reminder",
+    "Keyboard shortcuts" : "Keyboard shortcuts",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration} minutes"],
     "0 minutes" : "0 minutes",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hour","{duration} hours"],
@@ -241,7 +239,6 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "Please share anything that will help prepare for our meeting",
     "Could not book the appointment. Please try again later or contact the organizer." : "Could not book the appointment. Please try again later or contact the organizer.",
     "Back" : "Back",
-    "Create a new conversation" : "Create a new conversation",
     "Select conversation" : "Select conversation",
     "on" : "on",
     "at" : "at",
@@ -361,6 +358,11 @@ OC.L10N.register(
     "Update this occurrence" : "Update this occurrence",
     "Public calendar does not exist" : "Public calendar does not exist",
     "Maybe the share was deleted or has expired?" : "Maybe the share was deleted or has expired?",
+    "Remove participant" : "Remove participant",
+    "Yes" : "კი",
+    "No" : "არა",
+    "None" : "None",
+    "Create" : "Create",
     "from {formattedDate}" : "from {formattedDate}",
     "to {formattedDate}" : "to {formattedDate}",
     "on {formattedDate}" : "on {formattedDate}",
@@ -383,7 +385,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "No valid public calendars configured",
     "Speak to the server administrator to resolve this issue." : "Speak to the server administrator to resolve this issue.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website.",
     "By {authors}" : "By {authors}",
     "Subscribed" : "Subscribed",
     "Subscribe" : "Subscribe",
@@ -416,6 +417,10 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Attachment requires shared access","Attachments requiring shared access"],
     "Untitled event" : "Untitled event",
     "Close" : "Close",
+    "Selected" : "Selected",
+    "30 min" : "30 წთ",
+    "Participants" : "Participants",
+    "Submit" : "Submit",
     "Subscribe to {name}" : "Subscribe to {name}",
     "Export {name}" : "Export {name}",
     "Anniversary" : "Anniversary",
@@ -506,9 +511,13 @@ OC.L10N.register(
     "This is an event reminder." : "This is an event reminder.",
     "Appointment not found" : "Appointment not found",
     "User not found" : "User not found",
-    "Reminder" : "Reminder",
-    "+ Add reminder" : "+ Add reminder",
-    "Suggestions" : "Suggestions",
-    "Details" : "Details"
+    "Hidden" : "Hidden",
+    "Calendar name …" : "Calendar name …",
+    "Automatic ({detected})" : "Automatic ({detected})",
+    "Shortcut overview" : "Shortcut overview",
+    "Enable simplified editor" : "Enable simplified editor",
+    "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
+    "Time increments" : "Time increments",
+    "Show keyboard shortcuts" : "Show keyboard shortcuts"
 },
 "nplurals=2; plural=(n!=1);");
